#-*- coding: utf-8 -*-

'''
Tezo esempio (example_03.py) : Inserimento controlli;
                               sullo sfondo trasparente ...

Ho scoperto che la "trasparenza" avviene di sfondo in maniera alquanto
drastica : si crea un buco nella finestra e si vede lo schermo
sottostante, non un eventuale controllo sottostante.

Pertanto, l'approccio logico per avere delle didascalie SENZA sfondo
rimane quello di utilizzare i canvas.
In questo esempio si sono eliminate tuttwe le Label e si è utilizzato
un canvas per rappresentare l'immsgine di sfondo e mettere delle
etichette in corrispondenza delle entry.
'''

import tkinter as tk
from PIL import Image, ImageTk

class MainWin(tk.Tk):
    def __init__(self, img, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.title('Test background image & controls')
        self.img = Image.open(img)
        self.img_copy = self.img.copy()
        self.bg_image = ImageTk.PhotoImage(self.img)
        self.bg_cnv = tk.Canvas(self)
        self.bg_cnv.place(x=0, y=0, relwidth=1.0, relheight=1.0)
        self.load = True
        self.bg_cnv.bind('<Configure>', self._resize_background)
        self.user = tk.Entry(self, relief='sunken', border=2)
        self.user.grid(row=0, column=1, sticky='ew', padx=20, pady=4)
        self.pwd = tk.Entry(self, relief='sunken', border=2)
        self.pwd.grid(row=1, column=1, sticky='ew', padx=20, pady=4)
        btn = tk.Button(self, text='Accedi', bg='green', fg='yellow',
                        font='bold', border=3)
        btn.grid(row=2, column=0, pady=20)
        btn = tk.Button(self, text='Esci', bg='red', fg='yellow',
                        font='bold', border=3, command=self.destroy)
        btn.grid(row=2, column=1, pady=20)
        self.grid_columnconfigure(0, weight=1)
        self.grid_columnconfigure(1, weight=1)
        self.grid_rowconfigure(0, weight=1)
        self.grid_rowconfigure(1, weight=1)
        

    def _verify_init(self):
        w = self.img.width
        h = self.img.height
        self.configure(width=w, height=h)
        self.update()
        self.minsize(w, h)
        center_window(self)
        self.load = False
        
    def _resize_background(self, event):
        if self.load: self._verify_init()
        # cancella tutto
        self.bg_cnv.delete('all')
        # rappresenta l'immagine scalata
        w = self.bg_cnv.winfo_width()
        h = self.bg_cnv.winfo_height()
        x = self.bg_cnv.winfo_width() // 2
        y = self.bg_cnv.winfo_height() // 2
        self.img = self.img_copy.resize((w,h), Image.ANTIALIAS)
        self.bg_image = ImageTk.PhotoImage(self.img)
        self.bg_cnv.create_image(x, y, image=self.bg_image)
        # aggiorna la finestra, per poi avere le coordinate di griglia
        self.update()
        # scrive le didascalie in corrispondenza delle entry
        coords = self.grid_bbox(column=0, row=0)
        testo = 'Utente :'
        x = coords[2] // 3
        y = coords[3] // 2
        self.bg_cnv.create_text(x, y, text=testo, fill='yellow',
                                font='bold', anchor='w')
        coords = self.grid_bbox(column=0, row=1)
        testo = 'Passwd :'
        y = coords[1] + coords[3] // 2
        self.bg_cnv.create_text(x, y, text=testo, fill='yellow',
                                font='bold', anchor='w')
        


def center_window(gui):
    l = gui.winfo_screenwidth()
    a = gui.winfo_screenheight()
    wx = gui.winfo_reqwidth()
    wy = gui.winfo_reqheight()
    gui.geometry('{}x{}+{}+{}'.format(wx, wy, (l-wx)//2, (a-wy)//2))
    

if __name__ == '__main__':
    win = MainWin('resource/hal.png')
    win.mainloop()
